@@ -5,7 +5,7 @@ use warnings;
 
 use version;
 our $VERSION;
-$VERSION = "0.31";
+$VERSION = "0.32";
 
 use Net::SSLeay qw(make_headers get_https);
 use URI;
@@ -27,7 +27,7 @@ IPsonar - Wrapper to interact with the Lumeta IPsonar API
 
 =head1 VERSION
 
-Version 0.31
+Version 0.32
 (Mercurial Revision ID: 8cc8c5b56c62+)
 
 =cut
@@ -343,8 +343,11 @@ sub next_result {
     #End of Data
     if (
         $self->{params}->{'q.page'} == $self->{max_page}
-        && ( $self->{page_row} > $self->{max_row}
-            || !$self->{pagedata}[ $self->{page_row} ] )
+        && (
+            $self->{page_row} > $self->{max_row}
+            || ( ref( $self->{pagedata} ) eq 'ARRAY'
+                && !$self->{pagedata}[ $self->{page_row} ] )
+        )
       )
     {
         return;
